<?php

if (!function_exists('pipdig_custom_fonts_active')) {
	return;
}

function p3_custom_fonts_accept_mimes($mimes = array()) {
	$mimes['woff'] = "text/csv";
	$mimes['woff2'] = "text/csv";
	return $mimes;
}
add_action('upload_mimes', 'p3_custom_fonts_accept_mimes');

// https://gist.github.com/rmpel/e1e2452ca06ab621fe061e0fde7ae150
function p3_custom_wp_check_filetype_and_ext($values, $file, $filename, $mimes) {
	if (extension_loaded('fileinfo')) {
		$finfo = finfo_open(FILEINFO_MIME_TYPE);
		finfo_close($finfo);
		if (preg_match('/\.(woff)$/i', $filename)) {
			$values['ext']  = 'woff';
			$values['type'] = 'text/csv';
		} elseif ( preg_match('/\.(woff2)$/i', $filename)) {
			$values['ext']  = 'woff2';
			$values['type'] = 'text/csv';
		}
	} else {
		if (preg_match( '/\.(woff)$/i', $filename)) {
			$values['ext']  = 'woff';
			$values['type'] = 'text/csv';
		} elseif (preg_match( '/\.(woff2)$/i', $filename)) {
			$values['ext']  = 'woff2';
			$values['type'] = 'text/csv';
		}
	}
	return $values;
}
add_filter('wp_check_filetype_and_ext', 'p3_custom_wp_check_filetype_and_ext', 999999, 4);

function p3_custom_fonts_settings($settings_pages) {
	$settings_pages[] = array(
		'id' => 'pipdig-custom-fonts',
		'option_name' => 'pipdig_custom_fonts',
		'menu_title' => 'Custom Fonts',
		'parent' => 'pipdig',
		//'style' => 'no-boxes',
		'columns' => 1,
		'message' => 'Settings saved! You can edit the fonts in your theme from <a href="'.admin_url('customize.php?autofocus[section]=pipdig_fonts').'">this page</a> of the Customizer.'
	);
	return $settings_pages;
}
add_filter('mb_settings_pages', 'p3_custom_fonts_settings');


function p3_custom_fonts_settings_fields($meta_boxes) {
	$meta_boxes[] = array(
		'id' => 'font_1',
		'title' => 'Font 1',
		'settings_pages' => 'pipdig-custom-fonts',
		'fields' => array(
			array(
				'id' => 'pcf_1_woff',
				'name' => 'WOFF file',
				'type' => 'file_input',
			),
			array(
				'id' => 'pcf_1_woff2',
				'name' => 'WOFF2 file (optional)',
				'type' => 'file_input',
			),
			array(
				'id' => 'pcf_1_name',
				'name' => 'Font Name',
				'type' => 'text',
			),
		),
	);
	$meta_boxes[] = array(
		'id' => 'font_2',
		'title' => 'Font 2',
		'settings_pages' => 'pipdig-custom-fonts',
		'fields' => array(
			array(
				'id' => 'pcf_2_woff',
				'name' => 'WOFF file',
				'type' => 'file_input',
			),
			array(
				'id' => 'pcf_2_woff2',
				'name' => 'WOFF2 file (optional)',
				'type' => 'file_input',
			),
			array(
				'id' => 'pcf_2_name',
				'name' => 'Font Name',
				'type' => 'text',
			),
		),
	);
	$meta_boxes[] = array(
		'id' => 'font_3',
		'title' => 'Font 3',
		'settings_pages' => 'pipdig-custom-fonts',
		'fields' => array(
			array(
				'id' => 'pcf_3_woff',
				'name' => 'WOFF file',
				'type' => 'file_input',
			),
			array(
				'id' => 'pcf_3_woff2',
				'name' => 'WOFF2 file (optional)',
				'type' => 'file_input',
			),
			array(
				'id' => 'pcf_3_name',
				'name' => 'Font Name',
				'type' => 'text',
			),
		),
	);
	$meta_boxes[] = array(
		'id' => 'font_4',
		'title' => 'Font 4',
		'settings_pages' => 'pipdig-custom-fonts',
		'fields' => array(
			array(
				'id' => 'pcf_4_woff',
				'name' => 'WOFF file',
				'type' => 'file_input',
			),
			array(
				'id' => 'pcf_4_woff2',
				'name' => 'WOFF2 file (optional)',
				'type' => 'file_input',
			),
			array(
				'id' => 'pcf_4_name',
				'name' => 'Font Name',
				'type' => 'text',
			),
		),
	);
	return $meta_boxes;
}
add_filter('rwmb_meta_boxes', 'p3_custom_fonts_settings_fields');

// don't rename this function. It's used in theme functions.
function p3_custom_fonts_output() {
	if (!function_exists('rwmb_meta')) {
		return;
	}
	?>
	<!-- START pipdig Custom Fonts -->
	<style>
	<?php
	for ($x = 1; $x <= 4; $x++) {
		$pcf_woff = $pcf_name = '';
		$pcf_woff = rwmb_meta('pcf_'.$x.'_woff', array('object_type' => 'setting' ), 'pipdig_custom_fonts');
		$pcf_woff2 = rwmb_meta('pcf_'.$x.'_woff2', array('object_type' => 'setting' ), 'pipdig_custom_fonts');
		$pcf_name = rwmb_meta('pcf_'.$x.'_name', array('object_type' => 'setting'), 'pipdig_custom_fonts');
		if (!empty($pcf_woff) && !empty($pcf_name)) {
			?>
			@font-face {
				font-family: "<?php echo strip_tags($pcf_name); ?>";
				src: <?php if (!empty($pcf_woff2)) { ?>url("<?php echo esc_url($pcf_woff2); ?>") format("woff2"), <?php } ?>url("<?php echo esc_url($pcf_woff); ?>") format("woff");
				font-weight: normal;
				font-style: normal;
			}
			<?php
		}
	}
	?>
	</style>
	<!-- END pipdig Custom Fonts -->
	<?php

}
add_action('wp_head', 'p3_custom_fonts_output', 8);